@@ -203,6 +203,11 @@ RenderPlugin::RenderType RenderPlugin::renderType() const
     return UnknownRenderType;
 }
 
+RenderState RenderPlugin::renderState() const
+{
+    return RenderState( name() );
+}
+
 QString RenderPlugin::runtimeTrace() const
 {
     return name();
@@ -218,7 +223,7 @@ void RenderPlugin::restoreDefaultSettings()
     setSettings( QHash<QString,QVariant>() );
 }
 
-QStringList RenderPlugin::settingKeys()
+QStringList RenderPlugin::settingKeys() const
 {
     return settings().keys();
 }
@@ -236,7 +241,7 @@ bool RenderPlugin::setSetting( const QString & key, const QVariant & value )
     }
 }
 
-QVariant RenderPlugin::setting( const QString & name )
+QVariant RenderPlugin::setting( const QString & name ) const
 {
     return settings().value( name, QVariant() );
 }
