@@ -27,6 +27,8 @@ public:
     GeoDataAnimatedUpdate();
     GeoDataAnimatedUpdate( const GeoDataAnimatedUpdate &other );
     GeoDataAnimatedUpdate& operator=( const GeoDataAnimatedUpdate &other );
+    bool operator== (const GeoDataAnimatedUpdate &other) const;
+    bool operator!= (const GeoDataAnimatedUpdate &other) const;
     ~GeoDataAnimatedUpdate();
 
     /** Provides type information for downcasting a GeoNode */
@@ -35,9 +37,9 @@ public:
     double duration() const;
     void setDuration( double duration );
 
-    const GeoDataUpdate& update() const;
-    GeoDataUpdate& update();
-    void setUpdate( GeoDataUpdate &update );
+    const GeoDataUpdate* update() const;
+    GeoDataUpdate* update();
+    void setUpdate( GeoDataUpdate *update );
 
 private:
     GeoDataAnimatedUpdatePrivate* const d;
