@@ -20,6 +20,7 @@
 #include "GeoDataExtendedData.h"
 #include "GeoDataTimeStamp.h"
 #include "GeoDataTimeSpan.h"
+#include "GeoDataSchema.h"
 
 #include "GeoDataTypes.h"
 
@@ -29,7 +30,7 @@ namespace Marble
 {
 
 static GeoTagWriterRegistrar s_writerDocument( GeoTagWriter::QualifiedName(GeoDataTypes::GeoDataDocumentType,
-                                                                            kml::kmlTag_nameSpace22),
+                                                                            kml::kmlTag_nameSpaceOgc22),
                                                new KmlDocumentTagWriter() );
 
 KmlDocumentTagWriter::KmlDocumentTagWriter() :
@@ -48,6 +49,9 @@ bool KmlDocumentTagWriter::writeMid( const GeoNode *node, GeoWriter& writer ) co
     foreach( const GeoDataStyleMap &map, document->styleMaps() ) {
         writeElement( &map, writer );
     }
+    foreach( const GeoDataSchema &schema, document->schemas() ) {
+        writeElement( &schema, writer );
+    }
 
     QVector<GeoDataFeature*>::ConstIterator it =  document->constBegin();
     QVector<GeoDataFeature*>::ConstIterator const end = document->constEnd();
