@@ -21,7 +21,9 @@
 #include "GeoDataLookAt.h"
 #include "GeoDataCamera.h"
 #include "GeoWriter.h"
+#include "GeoDataRegion.h"
 #include "KmlElementDictionary.h"
+#include "KmlObjectTagWriter.h"
 
 namespace Marble
 {
@@ -51,6 +53,8 @@ bool KmlFeatureTagWriter::write( const Marble::GeoNode *node, GeoWriter &writer
     writer.writeStartElement( m_elementName );
 
     GeoDataFeature const *feature = static_cast<const GeoDataFeature*>(node);
+    KmlObjectTagWriter::writeIdentifiers( writer, feature );
+
     writer.writeOptionalElement( kml::kmlTag_name, feature->name() );
     writer.writeOptionalElement( kml::kmlTag_visibility, QString::number( feature->isVisible() ), "1" );
     writer.writeOptionalElement( "address", feature->address() );
@@ -86,6 +90,10 @@ bool KmlFeatureTagWriter::write( const Marble::GeoNode *node, GeoWriter &writer
         writeElement( &feature->extendedData(), writer );
     }
 
+    if ( !feature->region().latLonAltBox().isNull() ) {
+        writeElement( &feature->region(), writer );
+    }
+
     bool const result = writeMid( node, writer );
     writer.writeEndElement();
     return result;
