@@ -25,12 +25,9 @@ namespace Marble
 // the object type strings instead
 //FIXME: USE object strings provided by idis
 static GeoTagWriterRegistrar s_writerPlacemark( GeoTagWriter::QualifiedName(GeoDataTypes::GeoDataPlacemarkType,
-                                                                            kml::kmlTag_nameSpace22),
-                                               new KmlPlacemarkTagWriter() );
+                                                kml::kmlTag_nameSpaceOgc22), new KmlPlacemarkTagWriter() );
 
-
-bool KmlPlacemarkTagWriter::writeMid( const GeoNode *node,
-                                   GeoWriter& writer ) const
+bool KmlPlacemarkTagWriter::writeMid( const GeoNode *node, GeoWriter& writer ) const
 {
     const GeoDataPlacemark *placemark = static_cast<const GeoDataPlacemark*>(node);
 
@@ -40,6 +37,12 @@ bool KmlPlacemarkTagWriter::writeMid( const GeoNode *node,
         writeElement( placemark->geometry(), writer );
     }
 
+    if( placemark->isBalloonVisible() ){
+        QString string;
+        string.setNum( 1 );
+        writer.writeElement( kml::kmlTag_nameSpaceGx22, kml::kmlTag_balloonVisibility, string );
+    }
+
     return true;
 }
 
