@@ -16,7 +16,7 @@
 
 #include "GeoDataCoordinates.h"
 
-#include <QtCore/QDateTime>
+#include <QDateTime>
 
 namespace Marble
 {
@@ -27,6 +27,7 @@ class GeoDataPlacemark;
 class PlacemarkPositionProviderPlugin: public PositionProviderPlugin
 {
     Q_OBJECT
+    Q_PLUGIN_METADATA( IID "org.kde.edu.marble.PlacemarkPositionProviderPlugin" )
     Q_INTERFACES( Marble::PositionProviderPluginInterface )
 
  public:
