@@ -163,7 +163,7 @@ bool OverviewMap::isInitialized () const
     return true;
 }
 
-void OverviewMap::changeViewport( ViewportParams *viewport )
+void OverviewMap::setProjection( const ViewportParams *viewport )
 {
     GeoDataLatLonAltBox latLonAltBox = viewport->latLonAltBox( QRect( QPoint( 0, 0 ), viewport->size() ) );
     const qreal centerLon = viewport->centerLongitude();
@@ -185,6 +185,8 @@ void OverviewMap::changeViewport( ViewportParams *viewport )
         m_centerLat = centerLat;
         update();
     }
+
+    AbstractFloatItem::setProjection( viewport );
 }
 
 void OverviewMap::paintContent( QPainter *painter )
