@@ -12,8 +12,8 @@
 #include "WeatherModel.h"
 
 // Qt
-#include <QtCore/QTimer>
-#include <QtCore/QUrl>
+#include <QTimer>
+#include <QUrl>
 
 // Marble
 #include "BBCWeatherService.h"
@@ -27,14 +27,16 @@
 using namespace Marble;
 
 WeatherModel::WeatherModel( const MarbleModel *marbleModel, QObject *parent )
-    : AbstractDataPluginModel( "weather", marbleModel, parent ),
-      m_initialized( false )
+    : AbstractDataPluginModel( "weather", marbleModel, parent )
 {
     registerItemProperties( WeatherItem::staticMetaObject );
-    createServices();
+
+    // addService( new FakeWeatherService( marbleModel(), this ) );
+    addService( new BBCWeatherService( marbleModel, this ) );
+    addService( new GeoNamesWeatherService( marbleModel, this ) );
 
     m_timer = new QTimer();
-    connect( m_timer, SIGNAL(timeout()), SLOT(updateItems()) );
+    connect( m_timer, SIGNAL(timeout()), SLOT(clear()) );
 
     // Default interval = 3 hours
     setUpdateInterval( 3 );
@@ -54,10 +56,6 @@ void WeatherModel::setFavoriteItems( const QStringList& list )
         }
 
         AbstractDataPluginModel::setFavoriteItems( list );
-
-        if ( m_initialized && isFavoriteItemsOnly() ) {
-            updateItems();
-        }
     }
 }
 
@@ -95,18 +93,13 @@ void WeatherModel::downloadItemData( const QUrl& url,
 void WeatherModel::getAdditionalItems( const GeoDataLatLonAltBox& box,
                                qint32 number )
 {
-    m_lastBox = box;
-    m_lastNumber = number;
-
-    m_initialized = true;
-
-    emit additionalItemsRequested( box, marbleModel(), number );
+    emit additionalItemsRequested( box, number );
 }
 
 void WeatherModel::getItem( const QString &id )
 {
     foreach( AbstractWeatherService* service, m_services ) {
-        service->getItem( id, marbleModel() );
+        service->getItem( id );
     }
 }
 
@@ -115,20 +108,6 @@ void WeatherModel::parseFile( const QByteArray& file )
     emit parseFileRequested( file );
 }
 
-void WeatherModel::updateItems()
-{
-    clear();
-    emit additionalItemsRequested( m_lastBox, marbleModel(), m_lastNumber );
-    emit itemsUpdated();
-}
-
-void WeatherModel::createServices()
-{
-    // addService( new FakeWeatherService( this ) );
-    addService( new BBCWeatherService( this ) );
-    addService( new GeoNamesWeatherService( this ) );
-}
-
 void WeatherModel::downloadDescriptionFileRequested( const QUrl& url )
 {
     downloadDescriptionFile( url );
@@ -147,21 +126,13 @@ void WeatherModel::addService( AbstractWeatherService *service )
 
     connect( service, SIGNAL(createdItems(QList<AbstractDataPluginItem*>)),
              this, SLOT(addItemsToList(QList<AbstractDataPluginItem*>)) );
-    connect( service, SIGNAL(requestedDownload(QUrl,
-                                               QString, 
-                                               AbstractDataPluginItem*)),
-             this, SLOT(downloadItemData(QUrl,
-                                         QString,
-                                         AbstractDataPluginItem*)) );
+    connect( service, SIGNAL(requestedDownload(QUrl,QString,AbstractDataPluginItem*)),
+             this, SLOT(downloadItemData(QUrl,QString,AbstractDataPluginItem*)) );
     connect( service, SIGNAL(downloadDescriptionFileRequested(QUrl)),
              this, SLOT(downloadDescriptionFileRequested(QUrl)) );
 
-    connect( this, SIGNAL(additionalItemsRequested(const GeoDataLatLonAltBox,
-                                                   const MarbleModel*,
-                                                   qint32)),
-             service, SLOT(getAdditionalItems(const GeoDataLatLonAltBox,
-                                              const MarbleModel*,
-                                              qint32)) );
+    connect( this, SIGNAL(additionalItemsRequested(GeoDataLatLonAltBox,qint32)),
+             service, SLOT(getAdditionalItems(GeoDataLatLonAltBox,qint32)) );
     connect( this, SIGNAL(parseFileRequested(QByteArray)),
              service, SLOT(parseFile(QByteArray)) );
 
