@@ -46,7 +46,7 @@ void OsmNominatimRunner::returnNoResults()
     emit searchFinished( QVector<GeoDataPlacemark*>() );
 }
 
-void OsmNominatimRunner::search( const QString &searchTerm, const GeoDataLatLonAltBox &preferred )
+void OsmNominatimRunner::search( const QString &searchTerm, const GeoDataLatLonBox &preferred )
 {    
     QString base = "http://nominatim.openstreetmap.org/search?";
     QString query = "q=%1&format=xml&addressdetails=1&accept-language=%2";
