@@ -8,12 +8,14 @@
 // Copyright 2012       Bernhard Beschow <bbeschow@cs.tu-berlin.de>
 //
 
-#include <QtTest>
 
 #include "MarbleModel.h"
 #include "PluginManager.h"
 #include "AbstractDataPlugin.h"
 
+#include <QMetaType>
+#include <QTest>
+
 Q_DECLARE_METATYPE( const Marble::AbstractDataPlugin * )
 
 namespace Marble
